==> doppler-sdk-1.0.2.tar.gz: doppler-sdk-1.0.2/src/dopplersdk/services/integrations.py <==
from urllib.parse import quote
from .base import BaseService
from ..models.IntegrationsCreateRequest import (
    IntegrationsCreateRequest as IntegrationsCreateRequestModel,
)
from ..models.IntegrationsCreate200Response import (
    IntegrationsCreate200Response as IntegrationsCreate200ResponseModel,
)
from ..models.IntegrationsGet200Response import (
    IntegrationsGet200Response as IntegrationsGet200ResponseModel,
)
from ..models.IntegrationsUpdateRequest import (
    IntegrationsUpdateRequest as IntegrationsUpdateRequestModel,
)
from ..models.IntegrationsUpdate200Response import (
    IntegrationsUpdate200Response as IntegrationsUpdate200ResponseModel,
)
from ..models.IntegrationsDelete200Response import (
    IntegrationsDelete200Response as IntegrationsDelete200ResponseModel,
)


class Integrations(BaseService):
    def list(self):
        """
        List
        """

        url_endpoint = "/v3/integrations"
        headers = {}
        self._add_required_headers(headers)

        final_url = self._url_prefix + url_endpoint
        res = self._http.get(final_url, headers, True)
        return res

    def create(
        self, request_input: IntegrationsCreateRequestModel = None
    ) -> IntegrationsCreate200ResponseModel:
        """
        Create
        """

        url_endpoint = "/v3/integrations"
        headers = {"Content-type": "application/json"}
        self._add_required_headers(headers)

        final_url = self._url_prefix + url_endpoint
        res = self._http.post(final_url, headers, request_input, True)
        if res and isinstance(res, dict):
            return IntegrationsCreate200ResponseModel(**res)
        return res

    def get(self, integration: str) -> IntegrationsGet200ResponseModel:
        """
        Retrieve
        Parameters:
        ----------
            integration: str
                The integration slug
        """

        url_endpoint = "/v3/integrations/integration"
        headers = {}
        query_params = []
        self._add_required_headers(headers)
        if not integration:
            raise ValueError(
                "Parameter integration is required, cannot be empty or blank."
            )
        if integration:
            query_params.append(f"integration={integration}")
        final_url = self._url_prefix + url_endpoint + "?" + "&".join(query_params)
        res = self._http.get(final_url, headers, True)
        if res and isinstance(res, dict):
            return IntegrationsGet200ResponseModel(**res)
        return res

    def update(
        self, integration: str, request_input: IntegrationsUpdateRequestModel = None
    ) -> IntegrationsUpdate200ResponseModel:
        """
        Update
        Parameters:
        ----------
            integration: str
                The slug of the integration to update
        """

        url_endpoint = "/v3/integrations/integration"
        headers = {"Content-type": "application/json"}
        query_params = []
        self._add_required_headers(headers)
        if not integration:
            raise ValueError(
                "Parameter integration is required, cannot be empty or blank."
            )
        if integration:
            query_params.append(f"integration={integration}")
        final_url = self._url_prefix + url_endpoint + "?" + "&".join(query_params)
        res = self._http.put(final_url, headers, request_input, True)
        if res and isinstance(res, dict):
            return IntegrationsUpdate200ResponseModel(**res)
        return res

    def delete(self, integration: str) -> IntegrationsDelete200ResponseModel:
        """
        Delete
        Parameters:
        ----------
            integration: str
                The slug of the integration to delete
        """

        url_endpoint = "/v3/integrations/integration"
        headers = {}
        query_params = []
        self._add_required_headers(headers)
        if not integration:
            raise ValueError(
                "Parameter integration is required, cannot be empty or blank."
            )
        if integration:
            query_params.append(f"integration={integration}")
        final_url = self._url_prefix + url_endpoint + "?" + "&".join(query_params)
        res = self._http.delete(final_url, headers, True)
        if res and isinstance(res, dict):
            return IntegrationsDelete200ResponseModel(**res)
        return res

==> doppler-sdk-1.1.2.tar.gz: doppler-sdk-1.1.2/src/dopplersdk/services/integrations.py <==
from urllib.parse import quote
from ..net import query_serializer
from .base import BaseService
from ..models.IntegrationsListResponse import (
    IntegrationsListResponse as IntegrationsListResponseModel,
)
from ..models.IntegrationsCreateRequest import (
    IntegrationsCreateRequest as IntegrationsCreateRequestModel,
)
from ..models.IntegrationsCreateResponse import (
    IntegrationsCreateResponse as IntegrationsCreateResponseModel,
)
from ..models.IntegrationsGetResponse import (
    IntegrationsGetResponse as IntegrationsGetResponseModel,
)
from ..models.IntegrationsUpdateRequest import (
    IntegrationsUpdateRequest as IntegrationsUpdateRequestModel,
)
from ..models.IntegrationsUpdateResponse import (
    IntegrationsUpdateResponse as IntegrationsUpdateResponseModel,
)
from ..models.IntegrationsDeleteResponse import (
    IntegrationsDeleteResponse as IntegrationsDeleteResponseModel,
)


class Integrations(BaseService):
    def list(self) -> IntegrationsListResponseModel:
        """
        List
        """

        url_endpoint = "/v3/integrations"
        headers = {}
        self._add_required_headers(headers)

        final_url = self._url_prefix + url_endpoint
        res = self._http.get(final_url, headers, True)
        if res and isinstance(res, dict):
            return IntegrationsListResponseModel(**res)
        return res

    def create(
        self, request_input: IntegrationsCreateRequestModel = None
    ) -> IntegrationsCreateResponseModel:
        """
        Create
        """

        url_endpoint = "/v3/integrations"
        headers = {"Content-type": "application/json"}
        self._add_required_headers(headers)

        final_url = self._url_prefix + url_endpoint
        res = self._http.post(final_url, headers, request_input, True)
        if res and isinstance(res, dict):
            return IntegrationsCreateResponseModel(**res)
        return res

    def get(self, integration: str) -> IntegrationsGetResponseModel:
        """
        Retrieve
        Parameters:
        ----------
            integration: str
                The integration slug
        """

        url_endpoint = "/v3/integrations/integration"
        headers = {}
        query_params = []
        self._add_required_headers(headers)
        if not integration:
            raise ValueError(
                "Parameter integration is required, cannot be empty or blank."
            )
        query_params.append(
            query_serializer.serialize_query("form", False, "integration", integration)
        )
        final_url = self._url_prefix + url_endpoint + "?" + "&".join(query_params)
        res = self._http.get(final_url, headers, True)
        if res and isinstance(res, dict):
            return IntegrationsGetResponseModel(**res)
        return res

    def update(
        self, integration: str, request_input: IntegrationsUpdateRequestModel = None
    ) -> IntegrationsUpdateResponseModel:
        """
        Update
        Parameters:
        ----------
            integration: str
                The slug of the integration to update
        """

        url_endpoint = "/v3/integrations/integration"
        headers = {"Content-type": "application/json"}
        query_params = []
        self._add_required_headers(headers)
        if not integration:
            raise ValueError(
                "Parameter integration is required, cannot be empty or blank."
            )
        query_params.append(
            query_serializer.serialize_query("form", False, "integration", integration)
        )
        final_url = self._url_prefix + url_endpoint + "?" + "&".join(query_params)
        res = self._http.put(final_url, headers, request_input, True)
        if res and isinstance(res, dict):
            return IntegrationsUpdateResponseModel(**res)
        return res

    def delete(self, integration: str) -> IntegrationsDeleteResponseModel:
        """
        Delete
        Parameters:
        ----------
            integration: str
                The slug of the integration to delete
        """

        url_endpoint = "/v3/integrations/integration"
        headers = {}
        query_params = []
        self._add_required_headers(headers)
        if not integration:
            raise ValueError(
                "Parameter integration is required, cannot be empty or blank."
            )
        query_params.append(
            query_serializer.serialize_query("form", False, "integration", integration)
        )
        final_url = self._url_prefix + url_endpoint + "?" + "&".join(query_params)
        res = self._http.delete(final_url, headers, True)
        if res and isinstance(res, dict):
            return IntegrationsDeleteResponseModel(**res)
        return res
